@@ -20,8 +20,8 @@ use Try::Tiny          qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Get_Data qw( get_new_video_url );
-use App::YTDL::Helper   qw( sec_to_time encode_fs encode_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::GetData qw( get_new_video_url );
+use App::YTDL::Helper  qw( sec_to_time encode_fs encode_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
 
 END { print SHOW_CURSOR }
 
@@ -35,13 +35,9 @@ sub download_youtube {
             for my $fmt ( sort keys %{$info->{$ex}{$video_id}{file_name}} ) {
                 my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
                 try {
-                    if ( -f encode_fs( $file_name ) && $opt->{overwrite} ) {
-                        unlink encode_fs( $file_name ) or die $!
-                    }
+                    unlink encode_fs( $file_name ) or die $!                      if -f encode_fs( $file_name ) && $opt->{overwrite};
                     _download_video( $opt, $info, $ex, $video_id, $fmt, $nr );
-                    if ( $opt->{modify_timestamp} ) {
-                        timestamp_to_upload_date( $info, $ex, $video_id, $file_name );
-                    }
+                    timestamp_to_upload_date( $info, $ex, $video_id, $file_name ) if $opt->{modify_timestamp};
                 }
                 catch {
                     say "$video_id - $_";
@@ -65,10 +61,8 @@ sub _download_video {
         show_progress => 0,
     );
     print HIDE_CURSOR;
-    my $video_count = sprintf "%*s from %s", length $opt->{total_nr_videos}, $nr, $opt->{total_nr_videos};
-    if ( $nr > 1 ) {
-        say '  ' . '-' x length $video_count;
-    }
+    my $video_count = sprintf "%*s from %s", length $opt->{nr_videos}, $nr, $opt->{nr_videos};
+    printf "  %s\n", '-' x length $video_count if $nr > 1;
     binmode STDOUT, ':pop';
     printf "  %s (%s)\n", encode_stdout( $file_basename ), $info->{$ex}{$video_id}{duration} // '?';
     binmode STDOUT, ':encoding(console_out)';
@@ -79,6 +73,7 @@ sub _download_video {
     };
     my $p = {};
     my $try = 1;
+
     RETRY: while ( 1 ) {
         $p->{size}      = -s encode_fs( $file_name ) // 0;
         $p->{starttime} = gettimeofday;
@@ -168,9 +163,7 @@ sub _status_line {
                 $pr_status = ' ' x length $pr_status;
             }
             printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $pr_status, $incomplete;
-            if ( $p->{total} && $p->{total} == $file_size ) {
-                return 1;
-            }
+            return 1 if $p->{total} && $p->{total} == $file_size;
         }
     }
     else {
