@@ -7,18 +7,20 @@ use 5.010000;
 
 use Exporter qw( import );
 our @EXPORT_OK = qw( sec_to_time get_filename timestamp_to_upload_date encode_fs encode_stdout_lax encode_stdout
-                    write_json read_json sanitize_for_path HIDE_CURSOR SHOW_CURSOR );
+                    write_json read_json sanitize_for_path uni_capture uni_system HIDE_CURSOR SHOW_CURSOR );
 
 use Encode             qw( encode );
 use Time::Local        qw( timelocal );
 use Unicode::Normalize qw( NFC );
 
-use Encode::Locale     qw();
-use File::Touch        qw();
-use JSON               qw();
-use Term::Choose::Util qw( unicode_trim );
-use Unicode::GCString  qw();
+use Encode::Locale      qw();
+use File::Touch         qw();
+use IPC::System::Simple qw( capture system );
+use JSON                qw();
+use Term::Choose::Util  qw( unicode_trim );
+use Unicode::GCString   qw();
 
+use if $^O eq 'MSWin32', 'Win32::ShellQuote';
 
 use constant {
     HIDE_CURSOR => "\e[?25l",
@@ -31,11 +33,9 @@ sub get_filename {
     my ( $opt, $title, $ext, $fmt ) = @_;
     $ext //= 'unknown';
     $fmt //= '';
-    if ( length $fmt ) {
-        $fmt = '_' . $fmt;
-    }
-    my $len_ext   = Unicode::GCString->new( $ext )->columns();
-    my $len_fmt   = Unicode::GCString->new( $fmt )->columns();
+    $fmt = '_' . $fmt if length $fmt;
+    my $len_ext = Unicode::GCString->new( $ext )->columns();
+    my $len_fmt = Unicode::GCString->new( $fmt )->columns();
     my $max_len_title = $opt->{max_len_f_name} - ( $len_fmt + 1 + $len_ext );
     $title = unicode_trim( sanitize_for_path( $title ), $max_len_title );
     my $file_name = $title . $fmt . '.' . $ext;
@@ -81,9 +81,45 @@ sub encode_stdout {
 }
 
 
+sub uni_capture {
+    my ( @cmd ) = @_;
+    if ( wantarray ) {
+        my @capture;
+        if ( $^O eq 'MSWin32' ) {
+            @capture = capture( Win32::ShellQuote::quote_native( @cmd ) );
+        }
+        else {
+            @capture = capture( @cmd );
+        }
+        return @capture;
+    }
+    else {
+        my $capture;
+        if ( $^O eq 'MSWin32' ) {
+            $capture = capture( Win32::ShellQuote::quote_native( @cmd ) );
+        }
+        else {
+            $capture = capture( @cmd );
+        }
+        return $capture;
+    }
+}
+
+
+sub uni_system {
+    my ( @cmd ) = @_;
+    if ( $^O eq 'MSWin32' ) {
+        system( Win32::ShellQuote::quote_native( @cmd ) );
+    }
+    else {
+        system( @cmd );
+    }
+}
+
+
 sub sec_to_time {
     my ( $seconds, $long ) = @_;
-    die 'seconds: not defined'      if ! defined $seconds;
+    die 'seconds: not defined'                         if ! defined $seconds;
     die 'seconds: "' . $seconds . '" invalid datatype' if $seconds !~ /^[0-9]+\z/;
     my ( $minutes, $hours );
     if ( $seconds ) {
@@ -94,18 +130,10 @@ sub sec_to_time {
         $hours   = int( $minutes / 60 );
         $minutes = $minutes % 60;
     }
-    if ( $long ) {
-        return sprintf( "%d:%02d:%02d", $hours // 0, $minutes // 0, $seconds );
-    }
-    if ( $hours ) {
-        return sprintf( "%d:%02d:%02d", $hours, $minutes, $seconds );
-    }
-    elsif ( $minutes ) {
-        return sprintf( "%d:%02d", $minutes, $seconds );
-    }
-    else {
-        return sprintf( "0:%02d", $seconds );
-    }
+    return sprintf "%d:%02d:%02d", $hours // 0, $minutes // 0, $seconds if $long;
+    return sprintf "%d:%02d:%02d", $hours,      $minutes,      $seconds if $hours;
+    return sprintf "%d:%02d",                   $minutes,      $seconds if $minutes;
+    return sprintf "0:%02d",                                   $seconds;
 }
 
 
@@ -120,9 +148,7 @@ sub write_json {
 
 sub read_json {
     my ( $file ) = @_;
-    if ( ! -f encode_fs( $file ) ) {
-        return {};
-    }
+    return {} if ! -f encode_fs( $file );
     open my $fh, '<', encode_fs( $file ) or die $!;
     my $json = do { local $/; <$fh> };
     close $fh;
