@@ -11,17 +11,18 @@ our @EXPORT_OK = qw( get_download_infos );
 use File::Path            qw( make_path );
 use File::Spec::Functions qw( catfile catdir );
 
+use List::MoreUtils    qw( none );
 use Term::ANSIScreen   qw( :cursor :screen );
 use Term::Choose       qw( choose );
 use Term::Choose::Util qw( term_size );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Info_Print     qw( linefolded_print_info );
-use App::YTDL::Helper         qw( get_filename encode_stdout_lax encode_fs sanitize_for_path );
-use App::YTDL::History        qw( add_channel_to_history write_channel_history_to_file );
-use App::YTDL::Select_Quality qw( fmt_quality set_preferred_qualities );
-use App::YTDL::Options        qw( set_options );
+use App::YTDL::InfoPrint     qw( linefolded_print_info );
+use App::YTDL::Helper        qw( get_filename encode_stdout_lax encode_fs sanitize_for_path );
+use App::YTDL::History       qw( add_channel_to_history write_channel_history_to_file );
+use App::YTDL::SelectQuality qw( fmt_quality set_preferred_qualities );
+use App::YTDL::Options       qw( set_options );
 
 
 
@@ -47,9 +48,16 @@ sub get_download_infos {
 
         VIDEO: while ( @video_ids ) {
             my $video_id = shift @video_ids;
-            $count++;
             my $key_len = 13;
             my $print_array = linefolded_print_info( $opt, $info, $ex, $video_id, $key_len );
+            if ( ! keys %{$info->{$ex}{$video_id}{fmt_to_info}} ) {
+                delete $info->{$ex}{$video_id};
+                if ( none { $video_id eq $_ } @{$opt->{error_get_download_infos}} ) {
+                    push @{$opt->{error_get_download_infos}}, $video_id;
+                }
+                next VIDEO;
+            }
+            $count++;
 
             MENU: while ( 1 ) {
                 print "\n";
@@ -90,7 +98,7 @@ sub get_download_infos {
                         }
                     }
                     elsif ( $choice eq $delete ) {
-                        delete  $info->{$ex}{$video_id};
+                        delete $info->{$ex}{$video_id};
                         if ( ! @video_ids ) {
                             print up( 2 ), cldown;
                             print "\n";
@@ -156,19 +164,15 @@ sub get_download_infos {
                 $info->{$ex}{$video_id}{file_name}{$fmt} = catfile( $video_dir, get_filename( $opt, $title, $ext, $fmt ) );
 
                 $info->{$ex}{$video_id}{count} = $count;
-                $opt->{total_nr_videos}++;
+                $opt->{nr_videos}++;
 
             }
-            if ( $opt->{max_channels} ) {
-                add_channel_to_history( $opt, $info, $ex, $video_id );
-            }
+            add_channel_to_history( $opt, $info, $ex, $video_id ) if $opt->{max_channels};
         }
     }
     print "\n";
-    if ( $opt->{max_channels} ) {
-        write_channel_history_to_file( $opt );
-    }
-    if ( ! $opt->{total_nr_videos} ) {
+    write_channel_history_to_file( $opt ) if $opt->{max_channels};
+    if ( ! $opt->{nr_videos} ) {
         print locate( 1, 1 ), cldown;
         say "No videos";
         exit;
