@@ -11,26 +11,19 @@ our @EXPORT_OK = qw( search_and_merge );
 use File::Copy            qw( move );
 use File::Path            qw( make_path );
 use File::Spec::Functions qw( catfile catdir );
-use Time::Local           qw( timelocal );
 
-use File::Touch         qw();
-use File::Which         qw( which );
-use IPC::System::Simple qw( capture system );
 use Term::Choose        qw( choose );
 use Try::Tiny           qw( try catch );
 
-use if $^O eq 'MSWin32', 'Win32';
-
-use App::YTDL::Helper qw( get_filename timestamp_to_upload_date encode_fs );
+use App::YTDL::Helper qw( get_filename timestamp_to_upload_date encode_fs uni_capture uni_system );
 
 
 
 sub search_and_merge {
     my ( $opt, $info ) = @_;
-    if ( ! merge_requirements_ok( $opt ) ) {
-        return;
-    }
-    my @merged;
+    return if ! merge_requirements_ok( $opt );
+    my $first_line_out = 'Merged: ';
+
     EXTRACTOR: for my $ex ( keys %$info ) {
         VIDEO_ID: for my $video_id ( keys %{$info->{$ex}} ) {
             if ( keys %{$info->{$ex}{$video_id}{file_name}} == 2 ) {
@@ -56,7 +49,7 @@ sub search_and_merge {
                     push @{$opt->{error_merge}}, $video_id;
                     next VIDEO_ID
                 };
-                if ( ! $audio ) { #####
+                if ( ! $audio ) { #
                     say "$video_id: No file with audio-only stream!";
                     next VIDEO_ID;
                 }
@@ -64,6 +57,10 @@ sub search_and_merge {
                     say "$video_id: No file with video stream!";
                     next VIDEO_ID;
                 }
+                if ( $first_line_out ) {
+                    say $first_line_out;
+                    $first_line_out = '';
+                }
                 my $video_dir = $info->{$ex}{$video_id}{video_dir};
                 my $file_name = get_filename( $opt, $info->{$ex}{$video_id}{title}, $opt->{merge_ext}, $height );
                 my $out = catfile $video_dir, $file_name;
@@ -72,13 +69,11 @@ sub search_and_merge {
                         [ '  Skip', '  Overwrite' ],
                         { prompt => 'Already exists: ' . $file_name, layout => 3, index => 1 }
                     );
-                    if ( ! $overwrite_ok ) {
-                        next VIDEO_ID;
-                    }
+                    next VIDEO_ID if ! $overwrite_ok;
                 }
                 try {
                     _merge_video_with_audio( $opt, $video, $audio, $out );
-                    push @merged, $out;
+                    say ' ' .  $out;
                     if ( $opt->{merged_in_files} == 1 ) {
                         my $dir_orig_files = catdir $video_dir, $opt->{dir_stream_files};
                         make_path $dir_orig_files;
@@ -89,9 +84,7 @@ sub search_and_merge {
                         unlink $video or die $!;
                         unlink $audio or die $!;
                     }
-                    if ( $opt->{modify_timestamp} ) {
-                        timestamp_to_upload_date( $info, $ex, $video_id, $out );
-                    }
+                    timestamp_to_upload_date( $info, $ex, $video_id, $out ) if $opt->{modify_timestamp};
                 }
                 catch {
                     say "$video_id - Merge: $_";
@@ -101,57 +94,31 @@ sub search_and_merge {
             }
         }
     }
-    if ( @merged ) {
-        say 'Merged:';
-    }
-    for my $merged_file ( @merged ) {
-        say ' ' .  $merged_file;
-    }
 }
 
 
 sub _merge_video_with_audio {
     my ( $opt, $video, $audio, $out ) = @_;
-    my ( $fs_video, $fs_audio, $fs_out );
-    if ( $^O eq 'MSWin32' ) {
-        $fs_video = Win32::GetShortPathName( encode_fs( $video ) );
-        $fs_audio = Win32::GetShortPathName( encode_fs( $audio ) );
-        open my $fh, '>', encode_fs( $out ) or die $!; # overwrites $out
-        close $fh;
-        $fs_out = Win32::GetShortPathName( encode_fs( $out ) );
-    }
-    else {
-        $fs_video = encode_fs( $video );
-        $fs_audio = encode_fs( $audio );
-        $fs_out   = encode_fs( $out );
-    }
     my @cmd = ( $opt->{ffmpeg} );
     push @cmd, '-loglevel', $opt->{merge_loglevel};
     push @cmd, '-y';
-    push @cmd, '-i', $fs_video;
-    push @cmd, '-i', $fs_audio;
+    push @cmd, '-i', encode_fs( $video );
+    push @cmd, '-i', encode_fs( $audio );
     push @cmd, '-codec', 'copy';
     push @cmd, '-map', '0:v:0';
     push @cmd, '-map', '1:a:0';
-    push @cmd, $fs_out;
-    system( @cmd );
+    push @cmd, encode_fs( $out );
+    uni_system( @cmd );
 }
 
 
 sub _get_stream_info {
     my ( $opt, $file ) = @_;
-    my $fs_file;
-    if ( $^O eq 'MSWin32' ) {
-        $fs_file = Win32::GetShortPathName( encode_fs( $file ) );
-    }
-    else {
-        $fs_file   = encode_fs( $file );
-    }
     my @cmd = ( $opt->{ffprobe} );
     push @cmd, '-loglevel', 'warning';
     push @cmd, '-show_streams';
-    push @cmd, $fs_file;
-    my $stream_info = capture( @cmd );
+    push @cmd, encode_fs( $file );
+    my $stream_info = uni_capture( @cmd );
     return $stream_info;
 }
 
@@ -159,20 +126,16 @@ sub _get_stream_info {
 sub merge_requirements_ok {
     my ( $opt ) = @_;
     try {
-        $opt->{ffmpeg} = $^O eq 'MSWin32'
-            ? Win32::GetShortPathName( which( 'ffmpeg'  ) )
-            :                          which( 'ffmpeg' );
-        my $capture = capture( $opt->{ffmpeg}, '-version' );
+        my @cmd = ( $opt->{ffmpeg}, '-version' );
+        my $capture = uni_capture( @cmd );
     }
     catch {
         say "Could not find 'ffmpeg' - No merge.";
         return;
     };
     try {
-        $opt->{ffprobe} = $^O eq 'MSWin32'
-            ? Win32::GetShortPathName( which( 'ffprobe' ) )
-            :                          which( 'ffprobe' );
-        my $capture = capture( $opt->{ffprobe}, '-version' );
+        my @cmd = ( $opt->{ffprobe}, '-version' );
+        my $capture = uni_capture( @cmd );
     }
     catch {
         say "Could not find 'ffprobe' - No merge.";
@@ -182,6 +145,8 @@ sub merge_requirements_ok {
 }
 
 
+
+
 1;
 
 
